@@ -35,7 +35,7 @@
 #line 7 "strings_ashkenazi_poylish.gperf"
 struct event_title { char *name; char *dest; };
 
-#define TOTAL_KEYWORDS 189
+#define TOTAL_KEYWORDS 191
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 25
 #define MIN_HASH_VALUE 4
@@ -61,11 +61,11 @@ hash (register const char *str, register size_t len)
         0, 461, 461, 461, 461, 461,   5, 461, 461,   0,
        45,  40,  35,  20,  15,  10,   0, 461, 461,   0,
       461, 461, 461, 461, 461,  75,  55,  90, 135,  15,
-        5, 110,  45,   0,   0,  80,   5,  40, 140,   5,
+        5, 110,  45,   0,   0,  80,   5,  40, 140,  10,
         5,  35,  70,   0,   0,   5,  10, 165, 461, 125,
        10,   0, 461, 461, 461, 461, 461,  30,  10,  15,
         0,  35,  65,   0,  80,   5,  80,   0,  75,  55,
-       65, 100,   0,   5,   0,   0,  20,   5,   0,  25,
+       65, 100,   0,   5,   0,   0,  20,   5,   0,  60,
       461,  85, 110, 125, 461, 461, 461, 461, 461, 461,
       461, 461, 461, 461, 461, 461, 461, 461, 461, 461,
       461, 461, 461, 461, 461, 461, 461, 461, 461, 461,
@@ -118,189 +118,189 @@ hebcal_lookup_ashkenazi_poylish (register const char *str, register size_t len)
   static struct event_title wordlist[] =
     {
       {""}, {""}, {""}, {""},
-#line 173 "strings_ashkenazi_poylish.gperf"
+#line 175 "strings_ashkenazi_poylish.gperf"
       {"Sigd","Sigd"},
       {""},
-#line 175 "strings_ashkenazi_poylish.gperf"
-      {"Sukkot","Sukkos"},
-#line 187 "strings_ashkenazi_poylish.gperf"
-      {"Tu B'Av","Tu B'ov"},
-#line 176 "strings_ashkenazi_poylish.gperf"
-      {"Sukkot I","Sukkos I"},
 #line 177 "strings_ashkenazi_poylish.gperf"
+      {"Sukkot","Sukkos"},
+#line 189 "strings_ashkenazi_poylish.gperf"
+      {"Tu B'Av","Tu B'ov"},
+#line 178 "strings_ashkenazi_poylish.gperf"
+      {"Sukkot I","Sukkos I"},
+#line 179 "strings_ashkenazi_poylish.gperf"
       {"Sukkot II","Sukkos II"},
-#line 154 "strings_ashkenazi_poylish.gperf"
+#line 156 "strings_ashkenazi_poylish.gperf"
       {"Tevet","Teyves"},
-#line 128 "strings_ashkenazi_poylish.gperf"
+#line 129 "strings_ashkenazi_poylish.gperf"
       {"Pesach","Peisach"},
       {""},
-#line 129 "strings_ashkenazi_poylish.gperf"
-      {"Pesach I","Peisach I"},
 #line 130 "strings_ashkenazi_poylish.gperf"
+      {"Pesach I","Peisach I"},
+#line 131 "strings_ashkenazi_poylish.gperf"
       {"Pesach II","Peisach II"},
       {""},
 #line 15 "strings_ashkenazi_poylish.gperf"
       {"Sukkah","Sikku"},
-#line 178 "strings_ashkenazi_poylish.gperf"
+#line 180 "strings_ashkenazi_poylish.gperf"
       {"Sukkot II (CH''M)","Sukkos II (CH''M)"},
-#line 179 "strings_ashkenazi_poylish.gperf"
+#line 181 "strings_ashkenazi_poylish.gperf"
       {"Sukkot III (CH''M)","Sukkos III (CH''M)"},
       {""},
-#line 189 "strings_ashkenazi_poylish.gperf"
+#line 191 "strings_ashkenazi_poylish.gperf"
       {"Tu B'Shvat","Tu BiShvat"},
       {""},
-#line 131 "strings_ashkenazi_poylish.gperf"
-      {"Pesach II (CH''M)","Peisach II (CH''M)"},
 #line 132 "strings_ashkenazi_poylish.gperf"
+      {"Pesach II (CH''M)","Peisach II (CH''M)"},
+#line 133 "strings_ashkenazi_poylish.gperf"
       {"Pesach III (CH''M)","Peisach III (CH''M)"},
-#line 147 "strings_ashkenazi_poylish.gperf"
+#line 149 "strings_ashkenazi_poylish.gperf"
       {"Elul","Elul"},
-#line 137 "strings_ashkenazi_poylish.gperf"
-      {"Pesach VII","Peisach VII"},
 #line 138 "strings_ashkenazi_poylish.gperf"
+      {"Pesach VII","Peisach VII"},
+#line 139 "strings_ashkenazi_poylish.gperf"
       {"Pesach VIII","Peisach VIII"},
-#line 182 "strings_ashkenazi_poylish.gperf"
+#line 184 "strings_ashkenazi_poylish.gperf"
       {"Sukkot VI (CH''M)","Sukkos VI (CH''M)"},
       {""}, {""},
 #line 25 "strings_ashkenazi_poylish.gperf"
       {"Sotah","Soytu"},
       {""},
-#line 136 "strings_ashkenazi_poylish.gperf"
+#line 137 "strings_ashkenazi_poylish.gperf"
       {"Pesach VI (CH''M)","Peisach VI (CH''M)"},
       {""},
-#line 90 "strings_ashkenazi_poylish.gperf"
+#line 91 "strings_ashkenazi_poylish.gperf"
       {"Tzav","Tzav"},
-#line 183 "strings_ashkenazi_poylish.gperf"
+#line 185 "strings_ashkenazi_poylish.gperf"
       {"Sukkot VII (Hoshana Raba)","Sukkos VII (Hoyshano Rabo)"},
       {""},
-#line 168 "strings_ashkenazi_poylish.gperf"
+#line 170 "strings_ashkenazi_poylish.gperf"
       {"Shavuot","Shvuos"},
       {""},
-#line 169 "strings_ashkenazi_poylish.gperf"
+#line 171 "strings_ashkenazi_poylish.gperf"
       {"Shavuot I","Shvuos I"},
-#line 170 "strings_ashkenazi_poylish.gperf"
+#line 172 "strings_ashkenazi_poylish.gperf"
       {"Shavuot II","Shvuos II"},
-#line 83 "strings_ashkenazi_poylish.gperf"
+#line 84 "strings_ashkenazi_poylish.gperf"
       {"Shemot","Shmoys"},
 #line 33 "strings_ashkenazi_poylish.gperf"
       {"Shevuot","Shvios"},
-      {""}, {""},
-#line 62 "strings_ashkenazi_poylish.gperf"
-      {"Eikev","Aikev"},
+      {""}, {""}, {""},
 #line 32 "strings_ashkenazi_poylish.gperf"
       {"Makkot","Makkos"},
-#line 79 "strings_ashkenazi_poylish.gperf"
+#line 80 "strings_ashkenazi_poylish.gperf"
       {"Pekudei","Pkudey"},
       {""}, {""},
 #line 46 "strings_ashkenazi_poylish.gperf"
       {"Midot","Midos"},
-#line 74 "strings_ashkenazi_poylish.gperf"
+#line 75 "strings_ashkenazi_poylish.gperf"
       {"Miketz","Mikeitz"},
 #line 10 "strings_ashkenazi_poylish.gperf"
       {"Shabbat","Shabbos"},
-#line 49 "strings_ashkenazi_poylish.gperf"
+#line 50 "strings_ashkenazi_poylish.gperf"
       {"Parashat","Parshas"},
       {""},
-#line 70 "strings_ashkenazi_poylish.gperf"
+#line 71 "strings_ashkenazi_poylish.gperf"
       {"Lech-Lecha","Lech-Lecho"},
       {""},
-#line 58 "strings_ashkenazi_poylish.gperf"
+#line 59 "strings_ashkenazi_poylish.gperf"
       {"Bo","Boy"},
-#line 172 "strings_ashkenazi_poylish.gperf"
+#line 174 "strings_ashkenazi_poylish.gperf"
       {"Shushan Purim","Shushon Purim"},
       {""},
-#line 91 "strings_ashkenazi_poylish.gperf"
+#line 92 "strings_ashkenazi_poylish.gperf"
       {"Vaera","Voeiro"},
 #line 43 "strings_ashkenazi_poylish.gperf"
       {"Meilah","Meilu"},
 #line 41 "strings_ashkenazi_poylish.gperf"
       {"Temurah","Tmiru"},
-#line 166 "strings_ashkenazi_poylish.gperf"
+#line 168 "strings_ashkenazi_poylish.gperf"
       {"Shabbat Shuva","Shabbos Shuvo"},
       {""},
-#line 164 "strings_ashkenazi_poylish.gperf"
+#line 166 "strings_ashkenazi_poylish.gperf"
       {"Shabbat Rosh Chodesh","Shabbos Rosh Choydesh"},
-#line 186 "strings_ashkenazi_poylish.gperf"
+#line 188 "strings_ashkenazi_poylish.gperf"
       {"Tish'a B'Av","Tisho B'ov"},
-#line 73 "strings_ashkenazi_poylish.gperf"
+#line 74 "strings_ashkenazi_poylish.gperf"
       {"Metzora","Metzoyro"},
 #line 12 "strings_ashkenazi_poylish.gperf"
       {"Pesachim","Psuchim"},
       {""},
-#line 72 "strings_ashkenazi_poylish.gperf"
+#line 73 "strings_ashkenazi_poylish.gperf"
       {"Matot","Matos"},
       {""},
-#line 87 "strings_ashkenazi_poylish.gperf"
+#line 88 "strings_ashkenazi_poylish.gperf"
       {"Terumah","Trumo"},
 #line 36 "strings_ashkenazi_poylish.gperf"
       {"Zevachim","Zvuchim"},
-#line 167 "strings_ashkenazi_poylish.gperf"
+#line 169 "strings_ashkenazi_poylish.gperf"
       {"Shabbat Zachor","Shabbos Zochor"},
-#line 139 "strings_ashkenazi_poylish.gperf"
+#line 140 "strings_ashkenazi_poylish.gperf"
       {"Purim","Purim"},
       {""},
-#line 145 "strings_ashkenazi_poylish.gperf"
+#line 147 "strings_ashkenazi_poylish.gperf"
       {"Av","Ov"},
-#line 174 "strings_ashkenazi_poylish.gperf"
+#line 176 "strings_ashkenazi_poylish.gperf"
       {"Simchat Torah","Simchas Toyro"},
       {""},
-#line 162 "strings_ashkenazi_poylish.gperf"
-      {"Shabbat Nachamu","Shabbos Nachamu"},
-#line 89 "strings_ashkenazi_poylish.gperf"
+#line 63 "strings_ashkenazi_poylish.gperf"
+      {"Eikev","Aikev"},
+#line 90 "strings_ashkenazi_poylish.gperf"
       {"Toldot","Toldos"},
-#line 80 "strings_ashkenazi_poylish.gperf"
+#line 81 "strings_ashkenazi_poylish.gperf"
       {"Pinchas","Pinchos"},
 #line 9 "strings_ashkenazi_poylish.gperf"
       {"Berachot","Bruchos"},
-      {""}, {""},
-#line 69 "strings_ashkenazi_poylish.gperf"
+      {""},
+#line 164 "strings_ashkenazi_poylish.gperf"
+      {"Shabbat Nachamu","Shabbos Nachamu"},
+#line 70 "strings_ashkenazi_poylish.gperf"
       {"Korach","Koyrach"},
-#line 134 "strings_ashkenazi_poylish.gperf"
+#line 135 "strings_ashkenazi_poylish.gperf"
       {"Pesach Sheni","Peisach Sheini"},
       {""}, {""},
-#line 148 "strings_ashkenazi_poylish.gperf"
+#line 150 "strings_ashkenazi_poylish.gperf"
       {"Iyyar","Iyyor"},
       {""},
 #line 42 "strings_ashkenazi_poylish.gperf"
       {"Keritot","Krisos"},
-#line 163 "strings_ashkenazi_poylish.gperf"
+#line 165 "strings_ashkenazi_poylish.gperf"
       {"Shabbat Parah","Shabbos Poro"},
-#line 57 "strings_ashkenazi_poylish.gperf"
+#line 58 "strings_ashkenazi_poylish.gperf"
       {"Beshalach","Beshalach"},
 #line 45 "strings_ashkenazi_poylish.gperf"
       {"Tamid","Tumid"},
-#line 165 "strings_ashkenazi_poylish.gperf"
+#line 167 "strings_ashkenazi_poylish.gperf"
       {"Shabbat Shekalim","Shabbos Shkolim"},
-#line 66 "strings_ashkenazi_poylish.gperf"
+#line 67 "strings_ashkenazi_poylish.gperf"
       {"Ki Tavo","Ki-Sovo"},
 #line 39 "strings_ashkenazi_poylish.gperf"
       {"Bechorot","Bchoyros"},
       {""},
-#line 188 "strings_ashkenazi_poylish.gperf"
+#line 190 "strings_ashkenazi_poylish.gperf"
       {"Tu BiShvat","Tu BiShvat"},
-#line 96 "strings_ashkenazi_poylish.gperf"
+#line 97 "strings_ashkenazi_poylish.gperf"
       {"Vayera","Vayeiro"},
-#line 94 "strings_ashkenazi_poylish.gperf"
+#line 95 "strings_ashkenazi_poylish.gperf"
       {"Vayechi","Vayechi"},
-#line 56 "strings_ashkenazi_poylish.gperf"
+#line 57 "strings_ashkenazi_poylish.gperf"
       {"Bereshit","Braishis"},
       {""},
-#line 152 "strings_ashkenazi_poylish.gperf"
+#line 154 "strings_ashkenazi_poylish.gperf"
       {"Sivan","Sivon"},
 #line 11 "strings_ashkenazi_poylish.gperf"
       {"Eruvin","Airivin"},
       {""},
 #line 13 "strings_ashkenazi_poylish.gperf"
       {"Shekalim","Shkulim"},
-#line 142 "strings_ashkenazi_poylish.gperf"
+#line 144 "strings_ashkenazi_poylish.gperf"
       {"Adar","Odor"},
-#line 53 "strings_ashkenazi_poylish.gperf"
+#line 54 "strings_ashkenazi_poylish.gperf"
       {"Bechukotai","Bechikoysai"},
-#line 60 "strings_ashkenazi_poylish.gperf"
+#line 61 "strings_ashkenazi_poylish.gperf"
       {"Chukat","Chikas"},
-#line 85 "strings_ashkenazi_poylish.gperf"
+#line 86 "strings_ashkenazi_poylish.gperf"
       {"Shoftim","Shoftim"},
-#line 98 "strings_ashkenazi_poylish.gperf"
+#line 99 "strings_ashkenazi_poylish.gperf"
       {"Vayetzei","Vayeitzei"},
       {""},
 #line 30 "strings_ashkenazi_poylish.gperf"
@@ -309,125 +309,125 @@ hebcal_lookup_ashkenazi_poylish (register const char *str, register size_t len)
       {"Taanit","Taanis"},
 #line 40 "strings_ashkenazi_poylish.gperf"
       {"Arachin","Aruchin"},
-#line 88 "strings_ashkenazi_poylish.gperf"
+#line 89 "strings_ashkenazi_poylish.gperf"
       {"Tetzaveh","Tetzave"},
-#line 63 "strings_ashkenazi_poylish.gperf"
+#line 64 "strings_ashkenazi_poylish.gperf"
       {"Emor","Emoyr"},
       {""},
-#line 123 "strings_ashkenazi_poylish.gperf"
+#line 124 "strings_ashkenazi_poylish.gperf"
       {"Erev Tish'a B'Av","Erev Tisho Bov"},
 #line 22 "strings_ashkenazi_poylish.gperf"
       {"Ketubot","Ksibos"},
-#line 97 "strings_ashkenazi_poylish.gperf"
+#line 98 "strings_ashkenazi_poylish.gperf"
       {"Vayeshev","Vayeishev"},
-#line 75 "strings_ashkenazi_poylish.gperf"
+#line 76 "strings_ashkenazi_poylish.gperf"
       {"Mishpatim","Mishpotim"},
-#line 71 "strings_ashkenazi_poylish.gperf"
+#line 72 "strings_ashkenazi_poylish.gperf"
       {"Masei","Masei"},
-#line 151 "strings_ashkenazi_poylish.gperf"
+#line 153 "strings_ashkenazi_poylish.gperf"
       {"Sh'vat","Shvat"},
-#line 82 "strings_ashkenazi_poylish.gperf"
+#line 83 "strings_ashkenazi_poylish.gperf"
       {"Sh'lach","Shlach"},
       {""}, {""},
-#line 92 "strings_ashkenazi_poylish.gperf"
+#line 93 "strings_ashkenazi_poylish.gperf"
       {"Vaetchanan","Voeschanan"},
-#line 143 "strings_ashkenazi_poylish.gperf"
+#line 145 "strings_ashkenazi_poylish.gperf"
       {"Adar I","Odor Aleph"},
-#line 144 "strings_ashkenazi_poylish.gperf"
+#line 146 "strings_ashkenazi_poylish.gperf"
       {"Adar II","Odor Beis"},
 #line 37 "strings_ashkenazi_poylish.gperf"
       {"Menachot","Menuchos"},
       {""},
 #line 19 "strings_ashkenazi_poylish.gperf"
       {"Moed Katan","Moyed Koton"},
-#line 181 "strings_ashkenazi_poylish.gperf"
+#line 183 "strings_ashkenazi_poylish.gperf"
       {"Sukkot V (CH''M)","Sukkos V (CH''M)"},
-#line 119 "strings_ashkenazi_poylish.gperf"
+#line 120 "strings_ashkenazi_poylish.gperf"
       {"Erev Rosh Hashana","Erev Rosh-Hashono"},
       {""}, {""},
-#line 55 "strings_ashkenazi_poylish.gperf"
+#line 56 "strings_ashkenazi_poylish.gperf"
       {"Behar","Behar"},
-#line 135 "strings_ashkenazi_poylish.gperf"
+#line 136 "strings_ashkenazi_poylish.gperf"
       {"Pesach V (CH''M)","Peisach V (CH''M)"},
-#line 61 "strings_ashkenazi_poylish.gperf"
+#line 62 "strings_ashkenazi_poylish.gperf"
       {"Devarim","Dvurim"},
-#line 125 "strings_ashkenazi_poylish.gperf"
+#line 126 "strings_ashkenazi_poylish.gperf"
       {"Havdalah","Havdolo"},
       {""},
-#line 76 "strings_ashkenazi_poylish.gperf"
+#line 77 "strings_ashkenazi_poylish.gperf"
       {"Nasso","Nosso"},
       {""},
 #line 23 "strings_ashkenazi_poylish.gperf"
       {"Nedarim","Nedurim"},
-#line 190 "strings_ashkenazi_poylish.gperf"
+#line 192 "strings_ashkenazi_poylish.gperf"
       {"Tzom Gedaliah","Tzom Gdalyo"},
       {""},
-#line 103 "strings_ashkenazi_poylish.gperf"
+#line 104 "strings_ashkenazi_poylish.gperf"
       {"Yitro","Yisro"},
-#line 149 "strings_ashkenazi_poylish.gperf"
+#line 151 "strings_ashkenazi_poylish.gperf"
       {"Kislev","Kislev"},
-#line 159 "strings_ashkenazi_poylish.gperf"
+#line 161 "strings_ashkenazi_poylish.gperf"
       {"Shabbat HaChodesh","Shabbos HaChoydesh"},
-#line 52 "strings_ashkenazi_poylish.gperf"
+#line 53 "strings_ashkenazi_poylish.gperf"
       {"Bamidbar","Bamidbor"},
       {""},
-#line 101 "strings_ashkenazi_poylish.gperf"
+#line 102 "strings_ashkenazi_poylish.gperf"
       {"Vayishlach","Vayishlach"},
 #line 47 "strings_ashkenazi_poylish.gperf"
       {"Niddah","Niddu"},
 #line 38 "strings_ashkenazi_poylish.gperf"
       {"Chullin","Chillin"},
       {""}, {""},
-#line 118 "strings_ashkenazi_poylish.gperf"
+#line 119 "strings_ashkenazi_poylish.gperf"
       {"Erev Purim","Erev Purim"},
-#line 84 "strings_ashkenazi_poylish.gperf"
+#line 85 "strings_ashkenazi_poylish.gperf"
       {"Shmini","Shmini"},
 #line 35 "strings_ashkenazi_poylish.gperf"
       {"Horayot","Hoyroyos"},
-#line 65 "strings_ashkenazi_poylish.gperf"
+#line 66 "strings_ashkenazi_poylish.gperf"
       {"Kedoshim","Kdoyshim"},
       {""},
-#line 124 "strings_ashkenazi_poylish.gperf"
+#line 125 "strings_ashkenazi_poylish.gperf"
       {"Erev Yom Kippur","Erev Yom Kippur"},
       {""},
-#line 68 "strings_ashkenazi_poylish.gperf"
+#line 69 "strings_ashkenazi_poylish.gperf"
       {"Ki Tisa","Ki-Siso"},
       {""}, {""},
-#line 160 "strings_ashkenazi_poylish.gperf"
+#line 162 "strings_ashkenazi_poylish.gperf"
       {"Shabbat HaGadol","Shabbos HaGodol"},
-#line 117 "strings_ashkenazi_poylish.gperf"
+#line 118 "strings_ashkenazi_poylish.gperf"
       {"Erev Pesach","Erev Peisach"},
-#line 155 "strings_ashkenazi_poylish.gperf"
-      {"Rosh Hashana","Rosh Hashono"},
-#line 121 "strings_ashkenazi_poylish.gperf"
-      {"Erev Simchat Torah","Erev Simchas Toyro"},
-#line 156 "strings_ashkenazi_poylish.gperf"
-      {"Rosh Hashana I","Rosh Hashono I"},
 #line 157 "strings_ashkenazi_poylish.gperf"
-      {"Rosh Hashana II","Rosh Hashono II"},
+      {"Rosh Hashana","Rosh Hashono"},
 #line 122 "strings_ashkenazi_poylish.gperf"
+      {"Erev Simchat Torah","Erev Simchas Toyro"},
+#line 158 "strings_ashkenazi_poylish.gperf"
+      {"Rosh Hashana I","Rosh Hashono I"},
+#line 159 "strings_ashkenazi_poylish.gperf"
+      {"Rosh Hashana II","Rosh Hashono II"},
+#line 123 "strings_ashkenazi_poylish.gperf"
       {"Erev Sukkot","Erev Sukkos"},
-#line 100 "strings_ashkenazi_poylish.gperf"
+#line 101 "strings_ashkenazi_poylish.gperf"
       {"Vayikra","Vayikro"},
       {""}, {""},
-#line 78 "strings_ashkenazi_poylish.gperf"
+#line 79 "strings_ashkenazi_poylish.gperf"
       {"Noach","Noyach"},
-#line 140 "strings_ashkenazi_poylish.gperf"
+#line 141 "strings_ashkenazi_poylish.gperf"
       {"Purim Katan","Purim Koton"},
-#line 180 "strings_ashkenazi_poylish.gperf"
+#line 182 "strings_ashkenazi_poylish.gperf"
       {"Sukkot IV (CH''M)","Sukkos IV (CH''M)"},
 #line 18 "strings_ashkenazi_poylish.gperf"
       {"Megillah","Megillu"},
 #line 14 "strings_ashkenazi_poylish.gperf"
       {"Yoma","Yimu"},
-#line 153 "strings_ashkenazi_poylish.gperf"
+#line 155 "strings_ashkenazi_poylish.gperf"
       {"Tamuz","Tamuz"},
-#line 102 "strings_ashkenazi_poylish.gperf"
+#line 103 "strings_ashkenazi_poylish.gperf"
       {"Vezot Haberakhah","Zoys Habrocho"},
-#line 133 "strings_ashkenazi_poylish.gperf"
+#line 134 "strings_ashkenazi_poylish.gperf"
       {"Pesach IV (CH''M)","Peisach IV (CH''M)"},
       {""}, {""},
-#line 81 "strings_ashkenazi_poylish.gperf"
+#line 82 "strings_ashkenazi_poylish.gperf"
       {"Re'eh","Reei"},
       {""},
 #line 16 "strings_ashkenazi_poylish.gperf"
@@ -435,140 +435,142 @@ hebcal_lookup_ashkenazi_poylish (register const char *str, register size_t len)
       {""},
 #line 27 "strings_ashkenazi_poylish.gperf"
       {"Kiddushin","Kiddishin"},
-#line 195 "strings_ashkenazi_poylish.gperf"
+#line 197 "strings_ashkenazi_poylish.gperf"
       {"Yom Kippur","Yom Kippur"},
-#line 86 "strings_ashkenazi_poylish.gperf"
+#line 87 "strings_ashkenazi_poylish.gperf"
       {"Tazria","Tazria"},
 #line 21 "strings_ashkenazi_poylish.gperf"
       {"Yevamot","Yevumos"},
       {""}, {""}, {""}, {""}, {""},
-#line 146 "strings_ashkenazi_poylish.gperf"
+#line 148 "strings_ashkenazi_poylish.gperf"
       {"Cheshvan","Cheshvon"},
-#line 95 "strings_ashkenazi_poylish.gperf"
+#line 96 "strings_ashkenazi_poylish.gperf"
       {"Vayeilech","Vayeilech"},
       {""}, {""}, {""},
-#line 106 "strings_ashkenazi_poylish.gperf"
+#line 107 "strings_ashkenazi_poylish.gperf"
       {"Chanukah","Chanukko"},
       {""},
-#line 51 "strings_ashkenazi_poylish.gperf"
+#line 52 "strings_ashkenazi_poylish.gperf"
       {"Balak","Bulok"},
       {""}, {""}, {""}, {""},
 #line 28 "strings_ashkenazi_poylish.gperf"
       {"Baba Kamma","Buvu Kamu"},
       {""},
-#line 115 "strings_ashkenazi_poylish.gperf"
+#line 116 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 8th Day","Chanukko: 8th Day"},
-#line 107 "strings_ashkenazi_poylish.gperf"
+#line 108 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 1 Candle","Chanukko: 1 Candle"},
-#line 114 "strings_ashkenazi_poylish.gperf"
+#line 115 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 8 Candles","Chanukko: 8 Candles"},
       {""}, {""},
-#line 161 "strings_ashkenazi_poylish.gperf"
+#line 163 "strings_ashkenazi_poylish.gperf"
       {"Shabbat Machar Chodesh","Shabbos Mochor Choydesh"},
-      {""},
-#line 158 "strings_ashkenazi_poylish.gperf"
+#line 49 "strings_ashkenazi_poylish.gperf"
+      {"Daf Yomi","Daf Yoymi"},
+#line 160 "strings_ashkenazi_poylish.gperf"
       {"Shabbat Chazon","Shabbos Chazon"},
-#line 126 "strings_ashkenazi_poylish.gperf"
+#line 127 "strings_ashkenazi_poylish.gperf"
       {"Lag BaOmer","Lag Boymer"},
       {""}, {""}, {""},
-#line 113 "strings_ashkenazi_poylish.gperf"
+#line 114 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 7 Candles","Chanukko: 7 Candles"},
 #line 48 "strings_ashkenazi_poylish.gperf"
       {"Daf Yomi: %s %d","Daf Yoymi: %s %d"},
 #line 44 "strings_ashkenazi_poylish.gperf"
       {"Kinnim","Kinnim"},
       {""},
-#line 77 "strings_ashkenazi_poylish.gperf"
+#line 78 "strings_ashkenazi_poylish.gperf"
       {"Nitzavim","Nitzovim"},
-#line 112 "strings_ashkenazi_poylish.gperf"
+#line 113 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 6 Candles","Chanukko: 6 Candles"},
 #line 26 "strings_ashkenazi_poylish.gperf"
       {"Gitin","Gitin"},
-#line 59 "strings_ashkenazi_poylish.gperf"
+#line 60 "strings_ashkenazi_poylish.gperf"
       {"Chayei Sara","Chayei Suru"},
-#line 120 "strings_ashkenazi_poylish.gperf"
-      {"Erev Shavuot","Erev Shvuos"},
+#line 143 "strings_ashkenazi_poylish.gperf"
+      {"Rosh Chodesh","Rosh Choydesh"},
       {""},
-#line 111 "strings_ashkenazi_poylish.gperf"
+#line 112 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 5 Candles","Chanukko: 5 Candles"},
-#line 141 "strings_ashkenazi_poylish.gperf"
+#line 142 "strings_ashkenazi_poylish.gperf"
       {"Rosh Chodesh %s","Rosh Choydesh %s"},
       {""}, {""},
-#line 104 "strings_ashkenazi_poylish.gperf"
+#line 105 "strings_ashkenazi_poylish.gperf"
       {"Asara B'Tevet","Asoro Beteyves"},
 #line 31 "strings_ashkenazi_poylish.gperf"
       {"Sanhedrin","Sanhedrin"},
-#line 150 "strings_ashkenazi_poylish.gperf"
+#line 152 "strings_ashkenazi_poylish.gperf"
       {"Nisan","Nison"},
       {""},
 #line 34 "strings_ashkenazi_poylish.gperf"
       {"Avodah Zarah","Avoydu Zuru"},
       {""},
-#line 185 "strings_ashkenazi_poylish.gperf"
+#line 187 "strings_ashkenazi_poylish.gperf"
       {"Ta'anit Esther","Taanis Ester"},
       {""}, {""}, {""},
-#line 93 "strings_ashkenazi_poylish.gperf"
+#line 94 "strings_ashkenazi_poylish.gperf"
       {"Vayakhel","Vayakhel"},
-#line 110 "strings_ashkenazi_poylish.gperf"
+#line 111 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 4 Candles","Chanukko: 4 Candles"},
 #line 24 "strings_ashkenazi_poylish.gperf"
       {"Nazir","Nuzir"},
       {""}, {""}, {""},
-#line 109 "strings_ashkenazi_poylish.gperf"
+#line 110 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 3 Candles","Chanukko: 3 Candles"},
       {""},
-#line 196 "strings_ashkenazi_poylish.gperf"
+#line 198 "strings_ashkenazi_poylish.gperf"
       {"Yom Yerushalayim","Yom Yerusholayim"},
       {""},
-#line 99 "strings_ashkenazi_poylish.gperf"
+#line 100 "strings_ashkenazi_poylish.gperf"
       {"Vayigash","Vayigash"},
-#line 108 "strings_ashkenazi_poylish.gperf"
+#line 109 "strings_ashkenazi_poylish.gperf"
       {"Chanukah: 2 Candles","Chanukko: 2 Candles"},
       {""}, {""}, {""}, {""}, {""},
-#line 50 "strings_ashkenazi_poylish.gperf"
+#line 51 "strings_ashkenazi_poylish.gperf"
       {"Achrei Mot","Achrai"},
 #line 29 "strings_ashkenazi_poylish.gperf"
       {"Baba Metzia","Buvu Metziu"},
-      {""},
-#line 194 "strings_ashkenazi_poylish.gperf"
+#line 121 "strings_ashkenazi_poylish.gperf"
+      {"Erev Shavuot","Erev Shvuos"},
+#line 196 "strings_ashkenazi_poylish.gperf"
       {"Yom HaZikaron","Yom HaZikaron"},
       {""}, {""}, {""}, {""},
-#line 127 "strings_ashkenazi_poylish.gperf"
+#line 128 "strings_ashkenazi_poylish.gperf"
       {"Leil Selichot","Slichos"},
       {""}, {""}, {""}, {""}, {""},
-#line 171 "strings_ashkenazi_poylish.gperf"
+#line 173 "strings_ashkenazi_poylish.gperf"
       {"Shmini Atzeret","Shmini Atzeres"},
       {""}, {""}, {""},
 #line 20 "strings_ashkenazi_poylish.gperf"
       {"Chagigah","Chagigu"},
       {""}, {""}, {""}, {""},
-#line 64 "strings_ashkenazi_poylish.gperf"
+#line 65 "strings_ashkenazi_poylish.gperf"
       {"Ha'Azinu","Haazini"},
       {""}, {""},
-#line 116 "strings_ashkenazi_poylish.gperf"
+#line 117 "strings_ashkenazi_poylish.gperf"
       {"Days of the Omer","Oymer"},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""},
-#line 67 "strings_ashkenazi_poylish.gperf"
+#line 68 "strings_ashkenazi_poylish.gperf"
       {"Ki Teitzei","Ki-Seitzei"},
-#line 184 "strings_ashkenazi_poylish.gperf"
+#line 186 "strings_ashkenazi_poylish.gperf"
       {"Ta'anit Bechorot","Taanis Bchoros"},
-#line 54 "strings_ashkenazi_poylish.gperf"
+#line 55 "strings_ashkenazi_poylish.gperf"
       {"Beha'alotcha","Bahaaloschu"},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
-#line 193 "strings_ashkenazi_poylish.gperf"
+#line 195 "strings_ashkenazi_poylish.gperf"
       {"Yom HaShoah","Yom HaShoah"},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
-#line 191 "strings_ashkenazi_poylish.gperf"
+#line 193 "strings_ashkenazi_poylish.gperf"
       {"Tzom Tammuz","Tzom Tammuz"},
       {""}, {""}, {""}, {""}, {""}, {""}, {""},
-#line 192 "strings_ashkenazi_poylish.gperf"
+#line 194 "strings_ashkenazi_poylish.gperf"
       {"Yom HaAtzma'ut","Yom HaAtzma'ut"},
       {""}, {""}, {""}, {""}, {""}, {""}, {""},
-#line 197 "strings_ashkenazi_poylish.gperf"
+#line 199 "strings_ashkenazi_poylish.gperf"
       {"Yom HaAliyah","Yom HaAliyah"},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
@@ -580,7 +582,7 @@ hebcal_lookup_ashkenazi_poylish (register const char *str, register size_t len)
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""},
-#line 105 "strings_ashkenazi_poylish.gperf"
+#line 106 "strings_ashkenazi_poylish.gperf"
       {"Candle lighting","Hadlokas neyros"}
     };
 
